@@ -1,9 +1,5 @@
 def error_handler(app):
 
-    @app.errorhandler(301)
-    def handle_301_error(error):
-        return '资源的URI已更改', 301, []
-
     @app.errorhandler(400)
     def handle_400_error(error):
         return '请求参数错误', 400, []
