@@ -33,7 +33,7 @@ class Parameter():
             'param_form': self.param_form
         }
 
-    def verification(self, checking: dict, verify: dict, optional: dict = {}, null_value: bool = False) -> bool:
+    def verification(self, checking: dict, verify: dict, optional: dict = {}, null_value: bool = False) -> dict:
         for opt_k, opt_v in optional.items():
             # 没有选填参数时，填充预设的默认值
             if not checking.__contains__(opt_k):
@@ -59,4 +59,4 @@ class Parameter():
                 str_data = f'有多余的请求参数: {err}'
                 logging.warning(str_data)
                 abort(Response(str_data, 400, {}))
-        return True
+        return checking
